Learn R Programming

i2extras (version 0.2.1)

growth_rate: Calculate growth/decay rate

Description

Calculate growth/decay rate

Usage

growth_rate(x, ...)

# S3 method for default growth_rate(x, ...)

# S3 method for incidence2_fit growth_rate( x, alpha = 0.05, growth_decay_time = TRUE, include_warnings = FALSE, ... )

Arguments

x

The output of fit_curve().

...

Not currently used.

alpha

Value of alpha used to calculate confidence intervals; defaults to 0.05 which corresponds to a 95% confidence interval.

growth_decay_time

Should a doubling/halving time and corresponding confidence intervals be added to the output. Default TRUE.

include_warnings

Include models in output that triggered warnings but not errors. Defaults to FALSE.

Author

Tim Taylor